'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultStyles = exports.buttonStyles = exports.cardStyles = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _helperFunctions = require('./helperFunctions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cardStyles = exports.cardStyles = {
  none: {
    baseContainerStyle: {},
    baseImageStyle: {
      backgroundRepeat: 'no-repeat',
      backgroundPosition: 'center',
      backgroundSize: 'contain'
    },
    baseSternStyle: {},
    baseStarboardStyle: {},
    baseTitleStyle: {},
    baseSubtitleStyle: {}
  },
  neutral: {
    baseContainerStyle: {
      backgroundColor: 'rgba(255, 255, 255, 0.8)',
      position: 'relative',
      padding: '0.5rem 1rem',
      marginLeft: '1rem',
      minWidth: '16rem'
    },
    baseImageStyle: {
      overflow: 'hidden',
      backgroundPosition: 'center', //justifyContent: 'center', //alignItems: `center`,
      marginBottom: '8px',
      borderRadius: '3px 3px 0',
      display: 'flex',
      backgroundRepeat: 'no-repeat',
      backgroundSize: 'contain',
      height: '19rem'
    },
    baseSternStyle: {},
    baseStarboardStyle: {},
    baseTitleStyle: { textAlign: 'center', padding: '5px' },
    baseSubtitleStyle: { textAlign: 'center', padding: '5px' }
  }
};
var buttonStyles = exports.buttonStyles = {
  vivid: {
    transition: 'smooth',
    on: { backgroundColor: '#33aaff', color: '#eeeeee' },
    off: { backgroundColor: '#ffbb33', color: '#333333' },
    diff: 25
  },
  neutral: {
    transition: 'mix',
    on: { backgroundColor: '#bbbbbb' },
    off: { backgroundColor: '#ffffff' },
    disabled: { backgroundColor: '#ccc', color: '#888' },
    diff: 30
  },
  transparentNeutral: {
    transition: 'mix',
    on: { backgroundColor: '#bbbbbb55' },
    off: { backgroundColor: '#0000' },
    disabled: { backgroundColor: '#ccc', color: '#888' },
    diff: 30
  },
  link: { on: { color: '#888888' }, off: { color: '#222222' }, transition: 'text', diff: 20 },
  vampire: {
    on: { backgroundColor: '#bb2222', color: '#eeeeee' },
    off: { backgroundColor: '#e4e4e4', color: '#333333' },
    diff: 20,
    transition: 'smooth'
  },
  redden: {
    on: { backgroundColor: '#dd8888', color: '#eeeeee' },
    off: { backgroundColor: 'none', color: '#333333' },
    diff: 25,
    transition: 'contrast'
  },
  verdant: {
    on: { backgroundColor: '#88dd88', color: '#eeeeee' },
    off: { backgroundColor: 'none', color: '#333333' },
    diff: 20,
    transition: 'contrast'
  },
  traffic: {
    on: { backgroundColor: '#dd3333', color: '#eeeeee' },
    off: { backgroundColor: '#33dd33', color: '#333333' },
    diff: 20,
    transition: 'contrast'
  },
  violet: {
    on: { backgroundColor: '#dd33dd88', color: '#eeeeee' },
    off: { backgroundColor: '#cc88cc88', color: '#eeeeee' },
    diff: 25,
    transition: 'smooth'
  },
  delphiniumC: {
    on: { backgroundColor: '#dd33dd88', color: '#111' },
    off: { backgroundColor: '#ffffff', color: '#111' },
    diff: 25,
    transition: 'contrast'
  },
  delphiniumS: {
    on: { backgroundColor: '#dd33dd88', color: '#111' },
    off: { backgroundColor: '#ffffff', color: '#111' },
    diff: 25,
    transition: 'smooth'
  },
  delphiniumM: {
    on: { backgroundColor: '#dd33dd88', color: '#111' },
    off: { backgroundColor: '#ffffff', color: '#111' },
    diff: 25,
    transition: 'mix'
  },
  lisanthus: {
    on: { backgroundColor: '#591b64', color: '#eee' },
    off: { backgroundColor: '#ffffff', color: '#414' },
    diff: 25,
    transition: 'mix'
  },
  darken: {
    on: { backgroundColor: '#bbbbbb', color: '#eeeeee' },
    off: { backgroundColor: 'none', color: '#333333' },
    diff: 20,
    transition: 'contrast'
  },
  monochrome: {
    on: { backgroundColor: '#333333', color: '#f4f4f4' },
    off: { backgroundColor: '#fafafa', color: '#333333' },
    diff: 20,
    transition: 'smooth'
  },
  mild: {
    on: { backgroundColor: '#eeffff', color: '#111111' },
    off: { backgroundColor: '#fafafa', color: '#333333' },
    diff: 10,
    transition: 'smooth'
  }
};

var defaultStyles = exports.defaultStyles = {
  container: {
    position: 'relative',
    alignItems: 'center',
    cursor: 'default',
    display: 'flex',
    flex: '0 1 auto',
    flexDirection: 'column',
    margin: '0 1rem',
    opacity: '1',
    color: 'black',
    background: 'rgba(245, 245, 245, 0.85)',
    border: '1px solid #575757',
    zIndex: '2',
    borderRadius: '0.5rem'
  },
  body: {
    display: 'flex',
    flexDirection: 'column',
    background: '#fdfdfd',
    flex: '1 1 auto',
    padding: '2.4rem 1.2rem',
    borderRadius: '0 0 1rem 1rem',
    overflowY: 'auto'
  },
  background: {
    position: 'fixed',
    height: '100%',
    top: '0',
    left: '0',
    width: '100%',
    background: 'rgba(0, 0, 0, 0.5)',
    zIndex: '4',
    opacity: '1',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    WebkitTapHighlightColor: 'transparent'
  },
  header: {
    margin: '0',
    padding: '2rem 2rem 1.5rem 2rem',
    borderBottom: '0.5rem solid #f0f0f0',
    background: '#fafafa'
  },
  buttons: {
    borderTop: '1px solid #575757',
    padding: '0.5rem 0',
    width: '100%',
    background: 'white',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-end'
  },
  closemodalbutton: {
    top: '0.5rem',
    right: '0.5rem',
    cursor: 'pointer',
    position: 'absolute',
    background: 'white',
    borderRadius: '100%',
    display: 'flex',
    flexDirection: 'row-reverse'
  }
};